/*
 * Copyright (c) 2009 Lukas Mejdrech
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 * - Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 * - The name of the author may not be used to endorse or promote products
 *   derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/** @addtogroup ip
 *  @{
 */

/** @file
 */

#include <ipc/services.h>

#include "../../messages.h"
#include "../../modules.h"

#include "../../include/device.h"
#include "../../include/ip_interface.h"
#include "../../include/sockaddr.h"

#include "../../structures/packet/packet_client.h"

#include "../il_messages.h"

#include "ip_messages.h"

int ip_device_req( int ip_phone, device_id_t device_id, services_t service ){
	return generic_device_req( ip_phone, NET_IL_DEVICE, device_id, 0, service );
}

int ip_send_msg( int ip_phone, device_id_t device_id, packet_t packet, services_t sender ){
	return generic_send_msg( ip_phone, NET_IL_SEND, device_id, packet_get_id( packet ), sender );
}

int ip_connect_module( services_t service ){
	return connect_to_service( SERVICE_IP );
}

int ip_add_route_req( int ip_phone, device_id_t device_id, in_addr_t address, in_addr_t netmask, in_addr_t gateway ){
	return async_req_4_0( ip_phone, NET_IP_ADD_ROUTE, device_id, ( ipcarg_t ) gateway.s_addr, ( ipcarg_t ) address.s_addr, ( ipcarg_t ) netmask.s_addr );
}

int ip_set_gateway_req( int ip_phone, device_id_t device_id, in_addr_t gateway ){
	return async_req_2_0( ip_phone, NET_IP_SET_GATEWAY, device_id, ( ipcarg_t ) gateway.s_addr );
}

int ip_packet_size_req( int ip_phone, device_id_t device_id, size_t * addr_len, size_t * prefix, size_t * content, size_t * suffix ){
	return generic_packet_size_req( ip_phone, NET_IL_PACKET_SPACE, device_id, addr_len, prefix, content, suffix );
}

int ip_bind_service( services_t service, int protocol, services_t me, async_client_conn_t receiver, tl_received_msg_t tl_received_msg ){
	return bind_service( service, protocol, me, service, receiver );
}

/** @}
 */
